import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:taskservice/Common/JXColors.dart';
import 'package:taskservice/Model/JXServiceModel.dart';
import 'package:taskservice/database/DataBase.dart';
import 'package:taskservice/src/service/page_addservice.dart';
import '../custom_widgets.dart';

class CreateServiceList extends StatefulWidget {
  @override
  _CreateServiceList createState() => _CreateServiceList();
}

class _CreateServiceList extends State<CreateServiceList> {
  /*搜索栏*/
  TextEditingController _searchBar = TextEditingController();

  /*服务数组*/
  List <JXServiceModel> _baseServices = [];
  /*cells*/
  List <JXServiceModel> _displayItems = [];

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    updateServices();
  }
  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    /*标记选中服务*/
    dynamic obj = ModalRoute.of(context).settings.arguments;
    if (obj != null && obj['services'] != null) {
      List items = obj['services'];
      for (JXServiceModel service in items) {
        for (JXServiceModel base in _baseServices) {
          if (service.id == base.id) {
            base.isCheck = true;
          }
        }
      }
    }
    return MyScaffold(
      title: '服务列表',
      actions: <Widget>[
        IconButton(
          icon: Icon(Icons.add),
          iconSize: 34.0,
          tooltip: 'Add',
          onPressed: addBtnClickAction,
        ),
      ],
      body: Column(
        children: <Widget>[
          SearchBar(
            onTextChanged: (value){
              filterSevice();
            },
            hint: '输入服务类型',
            onBtnClear: (){
              setState(() {
                _searchBar.clear();
                filterSevice();
              });
            },
            searchController: _searchBar,
          ),
          Expanded(
            child: CustomScrollView(
              physics: BouncingScrollPhysics(),
              slivers: <Widget>[
                SliverList(
                  delegate: SliverChildBuilderDelegate((BuildContext context, int index) {
                    if (index < _displayItems.length) {
                      var service = _displayItems[index];
                      return theCellBuilder(service);
                    } else {
                      return null;
                    }
                  }),
                ),
              ],
            ),
          ),
          Container(
            padding: EdgeInsets.all(0),
            width: MediaQuery.of(context).size.width,
            height: 44.0,
            child: CupertinoButton(
              onPressed: saveBtnClickAction,
              color: JXColors.k101E40,
              borderRadius: BorderRadius.all(Radius.circular(0)),
              child: Text(
                '保存',
                style: TextStyle(
                  fontSize: 14,
                  color: JXColors.kFFFFFF,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  /*cell*/
  Widget theCellBuilder(JXServiceModel service) {
    return GestureDetector(
      onTap: (){
        service.isCheck = !service.isCheck;
        setState(() {});
      },
      child: Container(
        padding: EdgeInsets.symmetric(horizontal: 16),
        color: JXColors.kFFFFFF,
        alignment: Alignment.topCenter,
        child: Row(
          children: <Widget>[
            Container(
              width: 44.0,
              alignment: Alignment.center,
              child: Icon(
                  service.isCheck?Icons.radio_button_checked:Icons.radio_button_unchecked
              ),
            ),
            SizedBox(width: 12.0,),
            Expanded(
              child: Column(
                children: <Widget>[
                  SizedBox(height: 12,),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text('类型: ${service.kind}'),
                      Text('周期: ${service.cycle}${service.cycleUnit}'),
                    ],
                  ),
                  SizedBox(height: 12,),
                  Row(
                    children: <Widget>[
                      Text('备注 ${service.remark}'),
                    ],
                  ),
                  SizedBox(height: 12,),
                  Divider(
                    height: 2,
                    thickness: 2,
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  /*刷新服务项列表*/
  void updateServices() {
    MyDataBase.database.then((db) async {
      List <JXServiceModel> tmpItems = (await db.queryAllServices());
      for (JXServiceModel service in tmpItems) {
        for (JXServiceModel sub in _baseServices) {
          if (service.id == sub.id) {
            service.isCheck = sub.isCheck;
          }
        }
      }

      _baseServices.clear();
      _baseServices.addAll(tmpItems);
      filterSevice();
    });
  }

  /*筛选服务*/
  void filterSevice() {
    String text = _searchBar.text;
    print('筛选：$text');

    _displayItems.clear();
    if (text.isEmpty) {
      _displayItems.addAll(_baseServices);
    } else {
      for (JXServiceModel service in _baseServices) {
        bool has = false;
        /*filter kind*/
        if (service.kind.toLowerCase().contains(text.toLowerCase())) {
          _displayItems.add(service);
          has = true;
        }
      }
    }
    setState(() {});
  }

  /*保存*/
  void saveBtnClickAction() {
    /*筛选选中服务*/
    List <JXServiceModel> tmpItems = [];
    for (JXServiceModel service in _baseServices) {
      if (service.isCheck) {
        tmpItems.add(service);
      }
    }
    Navigator.of(context).pop(tmpItems);
  }

  /*添加信息的服务*/
  void addBtnClickAction() {
    Navigator.of(context).pushNamed('$CreateAddService', arguments: '').then((data) {
      if (data != null) {
        /*刷新数据显示*/
        updateServices();
      }
    });
  }
}